#from palettetools import palettetools
import palettetools as pt
import json

css = 'css'
json_string = 'json'
img1 = "https://assets.imgix.net/examples/bluehat.jpg"
img2 = "https://sherwinski.imgix.net/pineneedles.jpg"
img3 = "https://sherwinski.imgix.net/pineneedles1.jpg"
img4 = "https://www.google.com/"
'''
print("Parsing for bluehat.jpg")
print("Running with css...\n")
print(pt.extract_colors_css(img1))
print("Running with json...\n")
print(pt.extract_colors_json(img1))
print("\nRunning for text color...\n")
print(pt.overlay_text_color(img1))
'''
print("Parsing for pineneedles.jpg")
print("Running with css...\n")
print(pt.extract_colors_css(img2))
print("Running with json...\n")
print(pt.extract_colors_json(img2))
print("\nRunning for text color...\n")
print(pt.overlay_text_color(img2))

'''
print("---------------------")
resp = pt.extract_colors_json(img2)


try:
	json_obj = json.loads(resp)
except Exception as e:
	raise ValueError ('Invalid imgix-url, function call cannot be completed')
'''


import pytest
import palettetools as pt
import json
from test_palettetools_constants import *


def test_img1_palette_css():
	assert pt.extract_colors_css(IMG_BLUEHAT).find(CSS_BLUEHAT)

def test_img1_palette_json(): 
	assert pt.extract_colors_json(IMG_BLUEHAT) == JSON_BLUEHAT

def test_img1_color_overlay_BLACK():
	assert pt.overlay_text_color(IMG_BLUEHAT) == BLACK_HEX

def test_img2_palette_css():
	assert pt.extract_colors_css(IMG_PINE).find(CSS_PINE)

def test_img2_palette_json(): 
	assert pt.extract_colors_json(IMG_PINE) == JSON_PINE

def test_img2_color_overlay_WHITE():
	assert pt.overlay_text_color(IMG_PINE) == WHITE_HEX

def test_json_404_error():
	with pytest.raises(Exception):
		pt.extract_colors_json(BROKEN_URL)

def test_json_non_imgix_url():
	with pytest.raises(Exception):
		pt.extract_colors_json(INVALID_URL)

def test_css_404_error():
	with pytest.raises(Exception):
		pt.extract_colors_css(BROKEN_URL)

def test_css_non_imgix_url():
	with pytest.raises(Exception):
		pt.extract_colors_css(INVALID_URL)


# -*- coding: utf-8 -*-

import requests as req
import ast
from .constants import *

'''
	Tools for extracting/analyzing the color palette of an image hosted through imgix
	General usage: 

'''
def extract_colors_css(url):
	resp = req.get(url + PALETTE_URL_PARAM + 'css')
	resp.raise_for_status()
	css_str = resp.text

	for word in CSS_STRINGS:
		if(word not in css_str):
			raise Exception('Invalid imgix-url used, did not return an expected value')
			sys.exit(1)

	return css_str


def extract_colors_json(url):
	resp = req.get(url + PALETTE_URL_PARAM + 'json')
	resp.raise_for_status()

	try:
		json_obj = ast.literal_eval(resp.text)
	except Exception as err:
		raise Exception('Invalid imgix-url used, did not return an expected value')
		sys.exit(1)

	return json_obj

def overlay_text_color(url):
	resp = extract_colors_json(url)
	luminance = resp['average_luminance']

	if(luminance < .5):
		color = WHITE_HEX
	elif(luminance >= .5):
		color = BLACK_HEX

	return color


__all__ = [ 'extract_colors_css', 'extract_colors_json', 'overlay_text_color' ]



PALETTE_URL_PARAM = "?palette="
BLACK_HEX = 000
WHITE_HEX = fff
JSON_STRING = 'json'
CSS_STRINGS = ['.image-fg-ex-1', '.image-bg-ex-2', '.image-bg-vibrant', '.image-fg-muted-dark', 
				'.image-bg-muted', '.image-fg-vibrant-light', '.image-bg-muted-light', '.image-fg-vibrant-dark']

__all__ = [ 'PALETTE_URL_PARAM', 'BLACK_HEX', 'WHITE_HEX', 'JSON_STRING', 'CSS_STRINGS' ]


#!/usr/bin/env python
# -*- encoding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function

import io
import re
from glob import glob
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import splitext

from setuptools import find_packages
from setuptools import setup


def read(*names, **kwargs):
    with io.open(
        join(dirname(__file__), *names),
        encoding=kwargs.get('encoding', 'utf8')
    ) as fh:
        return fh.read()


setup(
    name='palettetools',
    version='0.7.0',
    license='BSD 2-Clause License',
    description='Color palette tools for processing imgix-served images.',
    long_description= read('README.rst'),
    author='sherwinski',
    author_email='sherwinhb@gmail.com',
    url='https://github.com/sherwinski/palette-tools',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    py_modules=[splitext(basename(path))[0] for path in glob('src/*.py')],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.7',
        'Topic :: Utilities',
    ],
    keywords=[
        'image', 'processing', 'color', 'palette', 'tools', 'imgix'
    ],
    install_requires=[
        'requests'
    ],
    tests_require=[
        'pytest'
    ],
)



BLACK_HEX = '000'
WHITE_HEX = 'fff'
IMG_BLUEHAT = "https://assets.imgix.net/examples/bluehat.jpg"
IMG_PINE = "https://sherwinski.imgix.net/pineneedles.jpg"
BROKEN_URL = "https://assets.imgix.net/examples/invalid"
INVALID_URL = "https://google.com"

CSS_BLUEHAT = """.image-fg-1 { color:#0d0c10 !important; } .image-bg-1 { background-color:#0d0c10 !important; } .image-fg-2 { color:#015091 !important; } .image-bg-2 { background-color:#015091 !important; } .image-fg-3 { color:#0870d3 !important; } .image-bg-3 { background-color:#0870d3 !important; } .image-fg-4 { color:#239be0 !important; } .image-bg-4 { background-color:#239be0 !important; } .image-fg-5 { color:#b1dfeb !important; } .image-bg-5 { background-color:#b1dfeb !important; } .image-fg-6 { color:#f0c9b4 !important; } .image-bg-6 { background-color:#f0c9b4 !important; } .image-fg-ex-1 { color:#000000 !important; } .image-bg-ex-1 { background-color:#000000 !important; } .image-fg-ex-2 { color:#ffffff !important; } .image-bg-ex-2 { background-color:#ffffff !important; } .image-fg-vibrant { color:#0d95e4 !important; } .image-bg-vibrant { background-color:#0d95e4 !important; } .image-fg-muted-dark { color:#38445c !important; } .image-bg-muted-dark { background-color:#38445c !important; } .image-fg-muted { color:#966760 !important; } .image-bg-muted { background-color:#966760 !important; } .image-fg-vibrant-light { color:#72c5f4 !important; } .image-bg-vibrant-light { background-color:#72c5f4 !important; } .image-fg-muted-light { color:#d8b6aa !important; } .image-bg-muted-light { background-color:#d8b6aa !important; } .image-fg-vibrant-dark { color:#015091 !important; } .image-bg-vibrant-dark { background-color:#015091 !important; }"""

JSON_BLUEHAT = {'colors': [{'red': 0.0509804, 'hex': '#0d0c10', 'blue': 0.0627451, 'green': 0.0470588}, {'red': 0.00392157, 'hex': '#015091', 'blue': 0.568627, 'green': 0.313725}, {'red': 0.0313725, 'hex': '#0870d3', 'blue': 0.827451, 'green': 0.439216}, {'red': 0.137255, 'hex': '#239be0', 'blue': 0.878431, 'green': 0.607843}, {'red': 0.694118, 'hex': '#b1dfeb', 'blue': 0.921569, 'green': 0.87451}, {'red': 0.941176, 'hex': '#f0c9b4', 'blue': 0.705882, 'green': 0.788235}], 'average_luminance': 0.708396, 'dominant_colors': {'vibrant': {'red': 0.0509804, 'hex': '#0d95e4', 'blue': 0.894118, 'green': 0.584314}, 'muted_light': {'red': 0.847059, 'hex': '#d8b6aa', 'blue': 0.666667, 'green': 0.713725}, 'muted': {'red': 0.588235, 'hex': '#966760', 'blue': 0.376471, 'green': 0.403922}, 'vibrant_dark': {'red': 0.00392157, 'hex': '#015091', 'blue': 0.568627, 'green': 0.313725}, 'vibrant_light': {'red': 0.447059, 'hex': '#72c5f4', 'blue': 0.956863, 'green': 0.772549}, 'muted_dark': {'red': 0.219608, 'hex': '#38445c', 'blue': 0.360784, 'green': 0.266667}}}

CSS_PINE = """.image-fg-1 { color:#f6e4ee !important; } .image-bg-1 { background-color:#f6e4ee !important; } .image-fg-2 { color:#d9afc3 !important; } .image-bg-2 { background-color:#d9afc3 !important; } .image-fg-3 { color:#aac373 !important; } .image-bg-3 { background-color:#aac373 !important; } .image-fg-4 { color:#6e9170 !important; } .image-bg-4 { background-color:#6e9170 !important; } .image-fg-5 { color:#375d2d !important; } .image-bg-5 { background-color:#375d2d !important; } .image-fg-6 { color:#2c4309 !important; } .image-bg-6 { background-color:#2c4309 !important; } .image-fg-ex-1 { color:#ffffff !important; } .image-bg-ex-1 { background-color:#ffffff !important; } .image-fg-ex-2 { color:#000000 !important; } .image-bg-ex-2 { background-color:#000000 !important; } .image-fg-vibrant { color:#aac373 !important; } .image-bg-vibrant { background-color:#aac373 !important; } .image-fg-muted-dark { color:#36522c !important; } .image-bg-muted-dark { background-color:#36522c !important; } .image-fg-muted { color:#98656d !important; } .image-bg-muted { background-color:#98656d !important; } .image-fg-vibrant-light { color:#e1acba !important; } .image-bg-vibrant-light { background-color:#e1acba !important; } .image-fg-muted-light { color:#d3abb5 !important; } .image-bg-muted-light { background-color:#d3abb5 !important; } .image-fg-vibrant-dark { color:#2c4309 !important; } .image-bg-vibrant-dark { background-color:#2c4309 !important; }"""

JSON_PINE = {'colors': [{'red': 0.964706, 'hex': '#f6e4ee', 'blue': 0.933333, 'green': 0.894118}, {'red': 0.85098, 'hex': '#d9afc3', 'blue': 0.764706, 'green': 0.686275}, {'red': 0.666667, 'hex': '#aac373', 'blue': 0.45098, 'green': 0.764706}, {'red': 0.431373, 'hex': '#6e9170', 'blue': 0.439216, 'green': 0.568627}, {'red': 0.215686, 'hex': '#375d2d', 'blue': 0.176471, 'green': 0.364706}, {'red': 0.172549, 'hex': '#2c4309', 'blue': 0.0352941, 'green': 0.262745}], 'average_luminance': 0.38134, 'dominant_colors': {'vibrant': {'red': 0.666667, 'hex': '#aac373', 'blue': 0.45098, 'green': 0.764706}, 'muted_light': {'red': 0.827451, 'hex': '#d3abb5', 'blue': 0.709804, 'green': 0.670588}, 'muted': {'red': 0.596078, 'hex': '#98656d', 'blue': 0.427451, 'green': 0.396078}, 'vibrant_dark': {'red': 0.172549, 'hex': '#2c4309', 'blue': 0.0352941, 'green': 0.262745}, 'vibrant_light': {'red': 0.882353, 'hex': '#e1acba', 'blue': 0.729412, 'green': 0.67451}, 'muted_dark': {'red': 0.211765, 'hex': '#36522c', 'blue': 0.172549, 'green': 0.321569}}}